#[non_exhaustive]pub enum ScenarioAction {
Send {
to: EndpointRef,
body: Option<Value>,
headers: Option<BTreeMap<String, Value>>,
method: String,
},
Receive {
from: EndpointRef,
deadline: Duration,
extract: Option<BTreeMap<String, String>>,
},
Sleep {
duration: Duration,
},
Validate {
target: ScenarioTarget,
expectation: ValidateExpectation,
deadline: Option<Duration>,
},
}Expand description
One ordered scenario action (ADR-0069 section 11, adopted from
Citrus: send, receive with a mandatory deadline, sleep,
validate).
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
Send
Send a message to an endpoint.
Fields

to: EndpointRefTarget endpoint reference.
Receive
Receive a message from an endpoint before the deadline passes.
Fields

from: EndpointRefSource endpoint reference.
Sleep
Pause the scenario for the given duration.
Validate
Assert an expectation against a scenario target.
Fields

target: ScenarioTargetWhat to validate: the last message received on an endpoint, a scenario variable, or a partner’s recorded traffic.

expectation: ValidateExpectationMatcher expectation: the message grammar for lastReceived
and variable targets, the partner count grammar for
partner targets.